% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metabarcoding_threshold.R
\docType{methods}
\name{normalize,metabarcoding.data-method}
\alias{normalize,metabarcoding.data-method}
\alias{normalize-methods,metabarcoding.data}
\title{Normalizes read counts by sample or by MOTU.}
\usage{
\S4method{normalize}{metabarcoding.data}(data, MARGIN = "sample",
  as.matrix = FALSE)
}
\arguments{
\item{data}{The \code{\linkS4class{metabarcoding.data}} instance
on normalisation have to be computed.}

\item{MARGIN}{Indicates if the sums have to be computed across 
samples or motus. 
Allowed values are :
\itemize{
  \item{'sample' or 1} for computing sum across samples
  \item{'motu' or 2} for computing sum across motus
  }}

\item{as.matrix}{Logical indicating if the normalized aboundancies
must be returned as a simple \code{matrix} (TRUE) or as a new
instance of the \code{\linkS4class{metabarcoding.data}} class
(FALSE, the default case).}
}
\value{
Returns a new instance of \code{\linkS4class{metabarcoding.data}}
        or a \code{numeric} matrix according to the \code{return.as.matrix}
        parameter.
}
\description{
Method \code{normalize} computes a normalized read aboundancy matrix
(relative frequency matrix) of a \code{\link{metabarcoding.data}} instance.
Normalization can be done according aboundancies per sample or per MOTU.
}
\examples{
# load termite data set from the ROBITools sample data
data(termes)

# Computes normalized aboundancies per sample
termes.norm = normalize(termes,MARGIN="sample")

# Computes normalized aboundancies per sample and
# stores the result as a new layer into the thermes
# structure
termes$normalized = normalize(termes,MARGIN="sample",as.matrix=TRUE)

}
\seealso{
\code{\linkS4class{metabarcoding.data}}
}
\author{
Aurelie Bonin
}
